@@ -28,10 +28,16 @@ G_BEGIN_DECLS
 gboolean gst_gl_context_gen_shader (GstGLContext * context,
     const gchar * shader_vertex_source,
     const gchar * shader_fragment_source, GstGLShader ** shader);
-void gst_gl_multiply_matrix4 (const gfloat * a, const gfloat * b, gfloat * result);
-void gst_gl_get_affine_transformation_meta_as_ndc_ext (GstVideoAffineTransformationMeta *
-    meta, gfloat * matrix);
-void gst_gl_set_affine_transformation_meta_from_ndc_ext (GstVideoAffineTransformationMeta * meta, const gfloat * matrix);
+
+/* Populated in the plugin init function */
+extern GQuark _gst_gl_tags_quark;
+
+/* This is public API in 1.28 */
+#define gst_meta_api_type_tags_contain_only(api,valid_tags) \
+  gst_gl_gst_meta_api_type_tags_contain_only(api,valid_tags)
+
+gboolean gst_gl_gst_meta_api_type_tags_contain_only (GType api,
+    const gchar ** valid_tags);
 
 G_END_DECLS
 
