@@ -643,7 +643,7 @@ gst_audio_aggregator_constructed (GObject * object)
 {
   GstAudioAggregator *aagg = GST_AUDIO_AGGREGATOR (object);
 
-  G_OBJECT_CLASS (gst_audio_aggregator_pad_parent_class)->constructed (object);
+  G_OBJECT_CLASS (gst_audio_aggregator_parent_class)->constructed (object);
 
   gst_audio_aggregator_translate_output_buffer_duration (aagg,
       DEFAULT_OUTPUT_BUFFER_DURATION);
