@@ -1128,8 +1128,12 @@ switch_and_activate_input_locked (GstURIDecodeBin3 * uridecodebin,
     GstSourcePad *old_spad = iterold->data;
     if (old_spad->db3_sink_pad) {
       GST_DEBUG_OBJECT (uridecodebin, "Releasing no longer used db3 pad");
+      /* Temporarily release play items lock to avoid deadlock if releasing the
+       * pad causes a message that calls back into our message handler. */
+      PLAY_ITEMS_UNLOCK (uridecodebin);
       gst_element_release_request_pad (uridecodebin->decodebin,
           old_spad->db3_sink_pad);
+      PLAY_ITEMS_LOCK (uridecodebin);
       old_spad->db3_sink_pad = NULL;
     }
   }
@@ -1586,6 +1590,7 @@ gst_uri_decode_bin3_set_property (GObject * object, guint prop_id,
       dec->download = g_value_get_boolean (value);
       break;
     case PROP_DOWNLOAD_DIR:
+      g_free (dec->download_dir);
       dec->download_dir = g_value_dup_string (value);
       break;
     case PROP_USE_BUFFERING:
