@@ -1075,6 +1075,7 @@ GST_START_TEST (test_appsrc_limits)
   GstBuffer *buffer;
   gulong probe_id;
   guint64 current_level;
+  GstFlowReturn ret;
 
   /* Test if the bytes limit works correctly with both leaky types */
   h = gst_harness_new ("appsrc");
@@ -1096,7 +1097,8 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 0 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* wait until the appsrc is blocked downstream */
   while (!gst_pad_is_blocking (srcpad))
@@ -1104,10 +1106,12 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 1 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 2 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The first buffer is not queued anymore but inside the pad probe */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1119,7 +1123,8 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 4 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The new buffer was dropped now, otherwise we would have 2 seconds queued */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1133,7 +1138,8 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 4 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The oldest buffer was dropped now, otherwise we would have only 1 second queued */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1191,7 +1197,8 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 0 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* wait until the appsrc is blocked downstream */
   while (!gst_pad_is_blocking (srcpad))
@@ -1199,10 +1206,12 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 1 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 2 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The first buffer is not queued anymore but inside the pad probe */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1214,7 +1223,8 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 4 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The new buffer was dropped now, otherwise we would have 2 seconds queued */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1228,7 +1238,8 @@ GST_START_TEST (test_appsrc_limits)
 
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 4 * GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The oldest buffer was dropped now, otherwise we would have only 1 second queued */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1287,7 +1298,8 @@ GST_START_TEST (test_appsrc_limits)
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 0 * GST_SECOND;
   GST_BUFFER_DURATION (buffer) = GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* wait until the appsrc is blocked downstream */
   while (!gst_pad_is_blocking (srcpad))
@@ -1296,11 +1308,13 @@ GST_START_TEST (test_appsrc_limits)
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 1 * GST_SECOND;
   GST_BUFFER_DURATION (buffer) = GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 2 * GST_SECOND;
   GST_BUFFER_DURATION (buffer) = GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The first buffer is not queued anymore but inside the pad probe */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1313,7 +1327,8 @@ GST_START_TEST (test_appsrc_limits)
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 4 * GST_SECOND;
   GST_BUFFER_DURATION (buffer) = GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The new buffer was dropped now, otherwise we would have more than 2 seconds queued */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1328,7 +1343,8 @@ GST_START_TEST (test_appsrc_limits)
   buffer = gst_buffer_new_and_alloc (100);
   GST_BUFFER_PTS (buffer) = 4 * GST_SECOND;
   GST_BUFFER_DURATION (buffer) = GST_SECOND;
-  gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  ret = gst_app_src_push_buffer (GST_APP_SRC (h->element), buffer);
+  fail_unless_equals_int (ret, GST_FLOW_OK);
 
   /* The oldest buffer was dropped now, otherwise we would have only 1 second queued */
   g_object_get (h->element, "current-level-bytes", &current_level, NULL);
@@ -1389,6 +1405,8 @@ send_event_chain_func (GstPad * pad, GstObject * parent, GstBuffer * buf)
   return GST_FLOW_OK;
 }
 
+static gboolean got_event = FALSE;
+
 static gboolean
 send_event_event_func (GstPad * pad, GstObject * parent, GstEvent * event)
 {
@@ -1396,6 +1414,7 @@ send_event_event_func (GstPad * pad, GstObject * parent, GstEvent * event)
   if (GST_EVENT_TYPE (event) == GST_EVENT_CUSTOM_DOWNSTREAM) {
     /* this event should arrive after the first buffer */
     fail_unless_equals_int (expect_offset, 1);
+    got_event = TRUE;
   }
   gst_event_unref (event);
   return TRUE;
@@ -1409,12 +1428,13 @@ GST_START_TEST (test_appsrc_send_custom_event)
 
   src = setup_appsrc ();
 
-  ASSERT_SET_STATE (src, GST_STATE_PLAYING, GST_STATE_CHANGE_SUCCESS);
-
   expect_offset = 0;
+  done = FALSE;
   gst_pad_set_chain_function (mysinkpad, send_event_chain_func);
   gst_pad_set_event_function (mysinkpad, send_event_event_func);
 
+  ASSERT_SET_STATE (src, GST_STATE_PLAYING, GST_STATE_CHANGE_SUCCESS);
+
   /* send a buffer, a custom event and a second buffer */
   buf = gst_buffer_new_and_alloc (1);
   GST_BUFFER_OFFSET (buf) = 0;
@@ -1435,6 +1455,197 @@ GST_START_TEST (test_appsrc_send_custom_event)
     g_cond_wait (&check_cond, &check_mutex);
   g_mutex_unlock (&check_mutex);
 
+  g_assert (got_event);
+
+  ASSERT_SET_STATE (src, GST_STATE_NULL, GST_STATE_CHANGE_SUCCESS);
+  cleanup_appsrc (src);
+}
+
+GST_END_TEST;
+
+enum ExpectedObj
+{
+  EXPECTED_STREAM_START,
+  EXPECTED_CAPS,
+  EXPECTED_SEGMENT,
+  EXPECTED_CUSTOM,
+  EXPECTED_BUFFER,
+};
+
+static enum ExpectedObj expected_obj;
+
+static gboolean
+send_event_before_buffer_event_func (GstPad * pad, GstObject * parent,
+    GstEvent * event)
+{
+  GST_LOG ("event %" GST_PTR_FORMAT, event);
+
+  if (expected_obj == EXPECTED_STREAM_START) {
+    g_assert_cmpuint (GST_EVENT_TYPE (event), ==, GST_EVENT_STREAM_START);
+    expected_obj = EXPECTED_CAPS;
+  } else if (expected_obj == EXPECTED_CAPS) {
+    g_assert_cmpuint (GST_EVENT_TYPE (event), ==, GST_EVENT_CAPS);
+    expected_obj = EXPECTED_SEGMENT;
+  } else if (expected_obj == EXPECTED_SEGMENT) {
+    g_assert_cmpuint (GST_EVENT_TYPE (event), ==, GST_EVENT_SEGMENT);
+    expected_obj = EXPECTED_CUSTOM;
+  } else if (expected_obj == EXPECTED_CUSTOM) {
+    g_assert_cmpuint (GST_EVENT_TYPE (event), ==, GST_EVENT_CUSTOM_DOWNSTREAM);
+    expected_obj = EXPECTED_BUFFER;
+  } else {
+    g_assert_not_reached ();
+  }
+
+  gst_event_unref (event);
+  return TRUE;
+}
+
+static GstFlowReturn
+send_event_before_buffer_chain_func (GstPad * pad, GstObject * parent,
+    GstBuffer * buf)
+{
+  GST_LOG ("buffer # %3u", (guint) GST_BUFFER_OFFSET (buf));
+
+  g_assert_cmpuint (expected_obj, ==, EXPECTED_BUFFER);
+
+  g_mutex_lock (&check_mutex);
+  done = TRUE;
+  g_cond_signal (&check_cond);
+  g_mutex_unlock (&check_mutex);
+
+  gst_buffer_unref (buf);
+  return GST_FLOW_OK;
+}
+
+/* send a custom event to appsrc before the first buffer */
+GST_START_TEST (test_appsrc_send_event_before_buffer)
+{
+  GstElement *src;
+  GstBuffer *buf;
+  GstCaps *caps;
+
+  src = setup_appsrc ();
+  g_object_set (src, "format", GST_FORMAT_TIME, NULL);
+
+  expected_obj = EXPECTED_STREAM_START;
+  done = FALSE;
+
+  gst_pad_set_event_function (mysinkpad, send_event_before_buffer_event_func);
+  gst_pad_set_chain_function (mysinkpad, send_event_before_buffer_chain_func);
+
+  ASSERT_SET_STATE (src, GST_STATE_PLAYING, GST_STATE_CHANGE_SUCCESS);
+
+  /* send a custom event and then the first buffer */
+  gst_element_send_event (src,
+      gst_event_new_custom (GST_EVENT_CUSTOM_DOWNSTREAM,
+          gst_structure_new ("custom", NULL, NULL)));
+
+  caps = gst_caps_from_string ("video/x-raw");
+  gst_app_src_set_caps (GST_APP_SRC_CAST (src), caps);
+  gst_caps_unref (caps);
+
+  buf = gst_buffer_new_and_alloc (2);
+  GST_BUFFER_OFFSET (buf) = 0;
+  fail_unless (gst_app_src_push_buffer (GST_APP_SRC_CAST (src),
+          buf) == GST_FLOW_OK);
+
+  g_mutex_lock (&check_mutex);
+  while (!done)
+    g_cond_wait (&check_cond, &check_mutex);
+  g_mutex_unlock (&check_mutex);
+
+  ASSERT_SET_STATE (src, GST_STATE_NULL, GST_STATE_CHANGE_SUCCESS);
+  cleanup_appsrc (src);
+}
+
+GST_END_TEST;
+
+/* send a custom event to appsrc before the first sample */
+GST_START_TEST (test_appsrc_send_event_before_sample)
+{
+  GstElement *src;
+  GstSample *sample;
+  GstBuffer *buf;
+  GstCaps *caps;
+  GstSegment segment;
+
+  src = setup_appsrc ();
+  g_object_set (src, "format", GST_FORMAT_TIME, NULL);
+
+  expected_obj = EXPECTED_STREAM_START;
+  done = FALSE;
+
+  gst_pad_set_event_function (mysinkpad, send_event_before_buffer_event_func);
+  gst_pad_set_chain_function (mysinkpad, send_event_before_buffer_chain_func);
+
+  ASSERT_SET_STATE (src, GST_STATE_PLAYING, GST_STATE_CHANGE_SUCCESS);
+
+  /* send a custom event and then the first sample */
+  gst_element_send_event (src,
+      gst_event_new_custom (GST_EVENT_CUSTOM_DOWNSTREAM,
+          gst_structure_new ("custom", NULL, NULL)));
+
+  buf = gst_buffer_new_and_alloc (2);
+  caps = gst_caps_from_string ("video/x-raw");
+  gst_segment_init (&segment, GST_FORMAT_TIME);
+  segment.start = 5;
+
+  sample = gst_sample_new (buf, caps, &segment, NULL);
+  fail_unless (gst_app_src_push_sample (GST_APP_SRC_CAST (src),
+          sample) == GST_FLOW_OK);
+
+  gst_caps_unref (caps);
+  gst_buffer_unref (buf);
+  gst_sample_unref (sample);
+
+  g_mutex_lock (&check_mutex);
+  while (!done)
+    g_cond_wait (&check_cond, &check_mutex);
+  g_mutex_unlock (&check_mutex);
+
+  ASSERT_SET_STATE (src, GST_STATE_NULL, GST_STATE_CHANGE_SUCCESS);
+  cleanup_appsrc (src);
+}
+
+GST_END_TEST;
+
+/* send a custom event to appsrc between the caps and the first buffer */
+GST_START_TEST (test_appsrc_send_event_between_caps_buffer)
+{
+  GstElement *src;
+  GstBuffer *buf;
+  GstCaps *caps;
+
+  src = setup_appsrc ();
+  g_object_set (src, "format", GST_FORMAT_TIME, NULL);
+
+  expected_obj = EXPECTED_STREAM_START;
+  done = FALSE;
+
+  gst_pad_set_event_function (mysinkpad, send_event_before_buffer_event_func);
+  gst_pad_set_chain_function (mysinkpad, send_event_before_buffer_chain_func);
+
+  ASSERT_SET_STATE (src, GST_STATE_PLAYING, GST_STATE_CHANGE_SUCCESS);
+
+  caps = gst_caps_from_string ("video/x-raw");
+  gst_app_src_set_caps (GST_APP_SRC_CAST (src), caps);
+  gst_caps_unref (caps);
+
+  /* send a custom event and then the first buffer */
+  gst_element_send_event (src,
+      gst_event_new_custom (GST_EVENT_CUSTOM_DOWNSTREAM,
+          gst_structure_new ("custom", NULL, NULL)));
+
+  buf = gst_buffer_new_and_alloc (2);
+  GST_BUFFER_OFFSET (buf) = 0;
+  fail_unless (gst_app_src_push_buffer (GST_APP_SRC_CAST (src),
+          buf) == GST_FLOW_OK);
+
+  g_mutex_lock (&check_mutex);
+  while (!done)
+    g_cond_wait (&check_cond, &check_mutex);
+  g_mutex_unlock (&check_mutex);
+
   ASSERT_SET_STATE (src, GST_STATE_NULL, GST_STATE_CHANGE_SUCCESS);
   cleanup_appsrc (src);
 }
@@ -1456,6 +1667,9 @@ appsrc_suite (void)
   tcase_add_test (tc_chain, test_appsrc_custom_segment_twice);
   tcase_add_test (tc_chain, test_appsrc_limits);
   tcase_add_test (tc_chain, test_appsrc_send_custom_event);
+  tcase_add_test (tc_chain, test_appsrc_send_event_before_buffer);
+  tcase_add_test (tc_chain, test_appsrc_send_event_before_sample);
+  tcase_add_test (tc_chain, test_appsrc_send_event_between_caps_buffer);
 
   if (RUNNING_ON_VALGRIND)
     tcase_add_loop_test (tc_chain, test_appsrc_block_deadlock, 0, 5);
