@@ -42,7 +42,7 @@
 #include <linux/input.h>
 #include <linux/joystick.h>
 
-#ifdef HAVE_X
+#ifdef HAVE_X11
 #include <gdk/gdkx.h>
 #endif
 #include <gst/video/videooverlay.h>
@@ -604,7 +604,7 @@ make_avi_msmpeg4v3_mp3_pipeline (const gchar * location)
 
   audio_bin = gst_bin_new ("a_decoder_bin");
   a_queue = gst_element_factory_make_or_warn ("queue", "a_queue");
-  a_decoder = gst_element_factory_make_or_warn ("mad", "a_dec");
+  a_decoder = gst_element_factory_make_or_warn ("mpg123audiodec", "a_dec");
   a_convert = gst_element_factory_make_or_warn ("audioconvert", "a_convert");
   audiosink = gst_element_factory_make_or_warn (ASINK, "a_sink");
 
@@ -668,8 +668,8 @@ make_mp3_pipeline (const gchar * location)
   pipeline = gst_pipeline_new ("app");
 
   src = gst_element_factory_make_or_warn (SOURCE, "src");
-  parser = gst_element_factory_make_or_warn ("mp3parse", "parse");
-  decoder = gst_element_factory_make_or_warn ("mad", "dec");
+  parser = gst_element_factory_make_or_warn ("mpegaudioparse", "parse");
+  decoder = gst_element_factory_make_or_warn ("mpg123audiodec", "dec");
   queue = gst_element_factory_make_or_warn ("queue", "queue");
   audiosink = gst_element_factory_make_or_warn (ASINK, "sink");
 
@@ -719,7 +719,7 @@ make_avi_pipeline (const gchar * location)
   gst_element_link (src, demux);
 
   audio_bin = gst_bin_new ("a_decoder_bin");
-  a_decoder = gst_element_factory_make_or_warn ("mad", "a_dec");
+  a_decoder = gst_element_factory_make_or_warn ("mpg123audiodec", "a_dec");
   audiosink = gst_element_factory_make_or_warn (ASINK, "a_sink");
   a_queue = gst_element_factory_make_or_warn ("queue", "a_queue");
   gst_element_link (a_decoder, a_queue);
@@ -779,15 +779,14 @@ make_mpeg_pipeline (const gchar * location)
   src = gst_element_factory_make_or_warn (SOURCE, "src");
   g_object_set (G_OBJECT (src), "location", location, NULL);
 
-  //demux = gst_element_factory_make_or_warn ("mpegdemux", "demux");
-  demux = gst_element_factory_make_or_warn ("flupsdemux", "demux");
+  demux = gst_element_factory_make_or_warn ("mpegdemux", "demux");
 
   gst_bin_add (GST_BIN (pipeline), src);
   gst_bin_add (GST_BIN (pipeline), demux);
   gst_element_link (src, demux);
 
   audio_bin = gst_bin_new ("a_decoder_bin");
-  a_decoder = gst_element_factory_make_or_warn ("mad", "a_dec");
+  a_decoder = gst_element_factory_make_or_warn ("mpg123audiodec", "a_dec");
   a_queue = gst_element_factory_make_or_warn ("queue", "a_queue");
   audiosink = gst_element_factory_make_or_warn (ASINK, "a_sink");
   gst_bin_add (GST_BIN (audio_bin), a_decoder);
@@ -864,7 +863,7 @@ make_mpegnt_pipeline (const gchar * location)
   gst_element_link (src, demux);
 
   audio_bin = gst_bin_new ("a_decoder_bin");
-  a_decoder = gst_element_factory_make_or_warn ("mad", "a_dec");
+  a_decoder = gst_element_factory_make_or_warn ("mpg123audiodec", "a_dec");
   a_queue = gst_element_factory_make_or_warn ("queue", "a_queue");
   audiosink = gst_element_factory_make_or_warn (ASINK, "a_sink");
   //g_object_set (G_OBJECT (audiosink), "fragment", 0x00180008, NULL);
@@ -2025,7 +2024,7 @@ shot_cb (GtkButton * button, gpointer data)
 
     /* get the snapshot buffer format now. We set the caps on the appsink so
      * that it can only be an rgb buffer. The only thing we have not specified
-     * on the caps is the height, which is dependant on the pixel-aspect-ratio
+     * on the caps is the height, which is dependent on the pixel-aspect-ratio
      * of the source material */
 #if 0
     caps = GST_BUFFER_CAPS (buffer);
@@ -2417,7 +2416,7 @@ msg_clock_lost (GstBus * bus, GstMessage * message, GstPipeline * data)
   gst_element_set_state (pipeline, GST_STATE_PLAYING);
 }
 
-#ifdef HAVE_X
+#ifdef HAVE_X11
 
 static gulong embed_xid = 0;
 
@@ -2476,7 +2475,7 @@ realize_cb (GtkWidget * widget, gpointer data)
   if (!gdk_window_ensure_native (window))
     g_error ("Couldn't create native window needed for GstVideoOverlay!");
 
-#ifdef HAVE_X
+#ifdef HAVE_X11
   embed_xid = GDK_WINDOW_XID (window);
   g_print ("Window realize: video window XID = %lu\n", embed_xid);
 #endif
@@ -2510,7 +2509,7 @@ connect_bus_signals (GstElement * pipeline)
 {
   GstBus *bus = gst_pipeline_get_bus (GST_PIPELINE (pipeline));
 
-#ifdef HAVE_X
+#ifdef HAVE_X11
   /* handle prepare-window-handle element message synchronously */
   gst_bus_set_sync_handler (bus, (GstBusSyncHandler) bus_sync_handler,
       pipeline, NULL);
@@ -2553,6 +2552,10 @@ connect_bus_signals (GstElement * pipeline)
   gst_object_unref (bus);
 }
 
+#if !GLIB_CHECK_VERSION(2,70,0)
+#define g_pattern_spec_match_string g_pattern_match_string
+#endif
+
 /* Return GList of paths described in location string */
 static GList *
 handle_wildcards (const gchar * location)
@@ -2572,7 +2575,7 @@ handle_wildcards (const gchar * location)
   }
 
   while ((name = g_dir_read_name (dir)) != NULL) {
-    if (g_pattern_match_string (pspec, name)) {
+    if (g_pattern_spec_match_string (pspec, name)) {
       res = g_list_append (res, g_strjoin ("/", path, name, NULL));
       g_print ("  found clip %s\n", name);
     }
@@ -2999,7 +3002,7 @@ main (int argc, char **argv)
    * asks for the XID of the window to render onto */
   gtk_widget_realize (window);
 
-#ifdef HAVE_X
+#ifdef HAVE_X11
   /* we should have the XID now */
   g_assert (embed_xid != 0);
 #endif
